@@ -36,12 +36,21 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->maximumVolume->setNum(0);
 
     context_create();
-    sources = get_source_names();
+#ifdef Q_WS_MAEMO_5
+    sources = new QStringList();
+    sources->append("Microphone");
+    sources->append("Bluetooth");
+#else
+    sources = (QStringList *) get_source_names();
+#endif
     ui->sourcesComboBox->addItems(*sources);
-    connect(ui->sourcesComboBox, SIGNAL(activated(QString)), this, SLOT(sourceChanged(QString)));
+    connect(ui->sourcesComboBox, SIGNAL(activated(int)), this, SLOT(sourceChanged(int)));
 
-    qDebug("Recording from: %s", sources->at(0).toLocal8Bit().constData());
-    connect_to_vu_meter_stream(sources->at(0).toLocal8Bit().constData(), this);
+#ifdef Q_WS_MAEMO_5
+    connect_to_vu_meter_stream("source.hw0", this);
+#else
+    connect_to_vu_meter_stream(sources->at(index).toLocal8Bit().constData(), this);
+#endif
 
     connect(this, SIGNAL(updateVuMeterSignal(float)), this, SLOT(updateValues(float)), Qt::QueuedConnection);
     connect(ui->maxLabel, SIGNAL(linkActivated(QString)), this, SLOT(resetMaxValue()));
@@ -71,14 +80,26 @@ void MainWindow::setDbScale(){
     resetMaxValue();
 }
 
-void MainWindow::sourceChanged(QString source){
-    qDebug("New source selected: %s", source.toLocal8Bit().constData());
+void MainWindow::sourceChanged(int index){
     disconnect_stream();
 
     resetMaxValue();
-    updateValues(0.);
+    emit updateVuMeterSignal(0.);
 
-    connect_to_vu_meter_stream(source.toLocal8Bit().constData(), this);
+#ifdef Q_WS_MAEMO_5
+    switch(index){
+    case 0:
+        connect_to_vu_meter_stream("source.hw0", this);
+        break;
+    case 1:
+        connect_to_vu_meter_stream("source.hw1", this);
+        break;
+    default:
+        qDebug("Unknown source!");
+    }
+#else
+    connect_to_vu_meter_stream(sources->at(index).toLocal8Bit().constData(), this);
+#endif
 }
 
 void MainWindow::updateValues(float value){
